@@ -15,8 +15,8 @@
 //! | --- | --- |
 //! | `-T, --template` | If set, treats `LOCAL_PATH` as a template with the current host as input data. |
 
-use crate::core::{Result, Error, Host};
-use crate::tasks::{TaskRunner, upload};
+use crate::prelude::*;
+use crate::tasks::upload;
 
 use clap::ArgMatches;
 use file_mode::Mode;
